@@ -3,7 +3,7 @@ from abstract_utilities import get_any_value,make_list
 from .call_log_data import get_logdata_from_signature
 from .call_transactions_data import get_transactions
 from typing import *
-from .queries import get_signature,get_sorted_txn_history,if_list_get_single
+from .queries import get_if_list,getZipRows,fetch_any_combo,get_signature,get_sorted_txn_history,if_list_get_single
 def get_creation_txn(txn_id=None,log_id=None,signature=None,pair_id=None):
     txns = get_transactions(txn_id=txn_id,log_id=log_id,signature=signature,pair_id=pair_id)
     txns = get_sorted_txn_history(txns)
@@ -74,7 +74,7 @@ def get_txn_history_from_selected_row(selected_row: Dict[str, Any]) -> Tuple[Any
     """
     pair_id = get_any_value(selected_row, 'pair_id')
     txn_history = fetch_any_combo(tableName='transactions',searchColumn='pair_id',searchValue=pair_id)
-    return pair_id, getZipRows(tableName='transactions',rows=txn_history)
+    return pair_id, txn_history
 
 def get_signature_transaction(signature: str) -> Any:
     """
