@@ -105,4 +105,4 @@ def get_db_from(tableName=None,columnNames=None,searchColumn=None,searchValue=No
     if isinstance(columnNames,list):
         columnNames = ','.join(columnNames)
     response = fetch_any_combo(tableName=tableName,columnNames=columnNames,searchColumn=searchColumn,searchValue=searchValue,zipit=zipit,count=count)
-    return getZipRows(tableName,response)
+    return response
